@@ -62,6 +62,7 @@ export class Application extends Adw.Application {
     constructor() {
         /* Translators: This is the program name. */
         GLib.set_application_name(_("Maps"));
+        Gtk.Window.set_default_icon_name(pkg.name);
 
         /* Needed to be able to use in UI files */
         _ensuredTypes.forEach((type) => GObject.type_ensure(type));
@@ -108,10 +109,9 @@ export class Application extends Adw.Application {
 
     _onOsmAccountSetupActivate() {
         let dialog =
-            Application.osmEdit.createAccountDialog(this._mainWindow, false);
+            Application.osmEdit.createAccountDialog(false);
 
-        dialog.show();
-        dialog.connect('response', () => dialog.destroy());
+        dialog.present(this._mainWindow);
     }
 
     _onSearchActivate(action, parameter) {
@@ -212,9 +212,7 @@ export class Application extends Adw.Application {
         let scheme = GLib.uri_parse_scheme(uri);
 
         if (scheme === 'geo') {
-            // we get a URI that looks like geo:///lat,lon, remove slashes
-            let geoURI = uri.replace(/\//g, '');
-            this._mainWindow.mapView.goToGeoURI(geoURI);
+            this._mainWindow.mapView.goToGeoURI(uri);
         } else if (scheme === 'http' || scheme === 'https') {
             this._mainWindow.mapView.goToHttpURL(uri);
         } else if (scheme === 'maps') {
@@ -255,7 +253,7 @@ export class Application extends Adw.Application {
                 this._mainWindow.showToast(_("An error has occurred"));
             } else {
                 // clear search entry
-                this._mainWindow.searchBar.placeEntry.text = '';
+                this._mainWindow.searchBar.text = '';
 
                 if (places) {
                     /* if there's only one place in results, show it directly
@@ -269,7 +267,7 @@ export class Application extends Adw.Application {
                         Application.normalStartup = false;
                         this._mainWindow.mapView.showPlace(places[0], true);
                     } else {
-                        this._mainWindow.searchBar.placeEntry.grab_focus();
+                        this._mainWindow.searchBar.grab_focus();
                         this._mainWindow.searchBar.updateResults(places, query,
                                                                  false);
                     }
@@ -362,7 +360,7 @@ export class Application extends Adw.Application {
     vfunc_shutdown() {
         // need to unparent popover children to avoid GTK warnings on exit
         if (this._mainWindow) {
-            this._mainWindow.searchBar.placeEntry.popover.unparent();
+            this._mainWindow.searchBar.popover.unparent();
             this._mainWindow.sidebar.unparentSearchPopovers();
         }
 
