@@ -39,7 +39,6 @@ import {MapView} from './mapView.js';
 import {PlaceBar} from './placeBar.js';
 import {PrintOperation} from './printOperation.js';
 import {SearchBar} from './searchBar.js';
-import * as Service from './service.js';
 import {ShapeLayer} from './shapeLayer.js';
 import {Sidebar} from './sidebar.js';
 import * as Utils from './utils.js';
@@ -50,34 +49,6 @@ const _ = gettext.gettext;
 const _CONFIGURE_ID_TIMEOUT = 100; // msecs
 const _PLACE_ENTRY_MARGIN = 36;
 
-class ShapeLayerFileChooser extends Gtk.FileChooserNative {
-
-    constructor(params) {
-        super(params);
-
-        let allFilter = new Gtk.FileFilter();
-        allFilter.set_name(_("All Layer Files"));
-        this.add_filter(allFilter);
-        this.set_filter(allFilter);
-        this.title = _("Open Shape Layer");
-
-        ShapeLayer.SUPPORTED_TYPES.forEach((layerClass) => {
-            let filter = new Gtk.FileFilter();
-            [filter, allFilter].forEach((f) => {
-                layerClass.mimeTypes.forEach((type) => {
-                    f.add_mime_type(type);
-                });
-            });
-            filter.set_name(layerClass.displayName);
-            this.add_filter(filter);
-        });
-    }
-}
-
-GObject.registerClass({
-    Template: 'resource:///org/gnome/Maps/ui/shape-layer-file-chooser.ui'
-}, ShapeLayerFileChooser);
-
 export class MainWindow extends Adw.ApplicationWindow {
 
     get mapView() {
@@ -180,11 +151,21 @@ export class MainWindow extends Adw.ApplicationWindow {
     _createSidebar() {
         let sidebar = new Sidebar({ mapView: this._mapView });
 
-        Application.routeQuery.connect('notify', () => this._setRevealSidebar(true));
+        Application.routeQuery.connect('notify', () => this._onRouteQueryNotify());
 
         return sidebar;
     }
 
+    _onRouteQueryNotify() {
+        const query = Application.routeQuery;
+        const sidebarShowing = this._splitView.show_sidebar;
+
+        /* reveal sidebar if it wasn't already visible and there are now
+         * filled points
+         */
+        this._setRevealSidebar(sidebarShowing || query.filledPoints.length > 0);
+    }
+
     _initPlaceBar() {
         this._placeBar = new PlaceBar({ mapView: this._mapView, mainWindow: this });
         this._placeBarContainer.append(this._placeBar);
@@ -311,30 +292,6 @@ export class MainWindow extends Adw.ApplicationWindow {
             },
         };
 
-        // when aerial tiles are available, add shortcuts to switch
-        if (Service.getService().tiles.aerial) {
-            actions['switch-to-street-view'] = {
-                accels: ['<Primary>1', '<Primary>KP_1'],
-                onActivate: () => this._onStreetViewActivate()
-            };
-
-            actions['switch-to-aearial-view'] = {
-                accels: ['<Primary>2', '<Primary>KP_2'],
-                onActivate: () => this._onAerialViewActivate()
-            };
-        }
-
-        if (Shumate.VectorRenderer.is_supported()) {
-            actions['enable-vector-layer'] = {
-                state: ['b', Application.settings.get('map-type') === MapView.MapType.VECTOR],
-                onChangeState: (action, variant) => {
-                    action.set_state(variant);
-                    const state = variant.get_boolean();
-                    this._setMapType(state ? MapView.MapType.VECTOR : MapView.MapType.STREET);
-                }
-            };
-        }
-
         Utils.addActions(this, actions, Application.settings);
     }
 
@@ -491,20 +448,18 @@ export class MainWindow extends Adw.ApplicationWindow {
     }
 
     _onFindActivate() {
-        let placeEntry = this._searchBar.placeEntry;
-
-        placeEntry.grab_focus();
-        placeEntry.select_region(0, placeEntry.text.length);
+        this._searchBar.grab_focus();
+        this._searchBar.select_region(0, this._searchBar.text.length);
     }
 
     _onBrowseActivate() {
-        this._searchBar.placeEntry.browsePois();
+        this._searchBar.browsePois();
     }
 
     _onShowSearchResultsActivate() {
-        if (this._searchBar.placeEntry.popover.numResults > 0) {
-            this._searchBar.placeEntry.popover.showResult();
-            this._searchBar.placeEntry.grab_focus();
+        if (this._searchBar.popover.numResults > 0) {
+            this._searchBar.popover.showResult();
+            this._searchBar.grab_focus();
         }
     }
 
@@ -560,8 +515,7 @@ export class MainWindow extends Adw.ApplicationWindow {
                                                                  height / 2);
 
         let dialog = new ExportViewDialog({
-            transient_for: this,
-            modal: true,
+            parentWindow: this,
             paintable: paintable,
             latitude: latitude,
             longitude: longitude,
@@ -570,8 +524,8 @@ export class MainWindow extends Adw.ApplicationWindow {
             mapView: this._mapView
         });
 
-        dialog.connect('response', () => dialog.destroy());
-        dialog.show();
+        dialog.connect('response', () => dialog.close());
+        dialog.present(this);
     }
 
     _rotateMap(angle) {
@@ -605,17 +559,6 @@ export class MainWindow extends Adw.ApplicationWindow {
         action.set_state(GLib.Variant.new('b', !state));
     }
 
-    _onStreetViewActivate() {
-        this._setMapType(MapView.MapType.STREET);
-    }
-
-    _onAerialViewActivate() {
-        // don't attempt to switch to aerial if we don't have tiles for it
-        if (Service.getService().tiles.aerial) {
-            this._setMapType(MapView.MapType.AERIAL);
-        }
-    }
-
     _onToggleSidebarChangeState(action, variant) {
         action.set_state(variant);
 
@@ -634,7 +577,7 @@ export class MainWindow extends Adw.ApplicationWindow {
     }
 
     _onAboutActivate() {
-        let about = new Adw.AboutWindow({
+        let about = new Adw.AboutDialog({
             designers: [ 'Jakub Steiner <jimmac@gmail.com>',
                          'Andreas Nilsson <nisses.mail@home.se>' ],
             developers: [ 'Zeeshan Ali (Khattak) <zeeshanak@gnome.org>',
@@ -650,42 +593,29 @@ export class MainWindow extends Adw.ApplicationWindow {
             license_type: Gtk.License.GPL_2_0,
             version: pkg.version,
             website: 'https://apps.gnome.org/Maps/',
-            issue_url: 'https://gitlab.gnome.org/GNOME/gnome-maps/-/issues/new',
-            transient_for: this
+            issue_url: 'https://gitlab.gnome.org/GNOME/gnome-maps/-/issues/'
         });
 
         this._addAttribution(about);
 
-        about.present();
+        about.present(this);
     }
 
     _addAttribution(about) {
-        let tileProviderInfo = Service.getService().tileProviderInfo;
-        let photonGeocode = Service.getService().photonGeocode;
         let attribution = _("Map data by %s and contributors").format('<a href="https://www.openstreetmap.org">OpenStreetMap</a>');
         about.add_legal_section(_("Map Data Provider"), null, Gtk.License.CUSTOM, attribution);
 
-        if (tileProviderInfo) {
-            let tileProviderString;
-            if (tileProviderInfo.url) {
-                tileProviderString = '<a href="' + tileProviderInfo.url + '">' +
-                                     tileProviderInfo.name + '</a>';
-            } else {
-                tileProviderString = tileProviderInfo.name;
-            }
-
-            about.add_legal_section(
-                _("Map Tile Provider"),
-                null,
-                Gtk.License.CUSTOM,
-                /* Translators: this is an attribution string giving credit to the
-                * tile provider where the %s placeholder is replaced by either
-                * the bare name of the tile provider, or a linkified URL if one
-                * is available
-                */
-                _("Map tiles provided by %s").format(tileProviderString)
-            );
-        }
+        about.add_legal_section(
+            _("Map Tile Provider"),
+            null,
+            Gtk.License.CUSTOM,
+            /* Translators: this is an attribution string giving credit to the
+            * tile provider where the %s placeholder is replaced by either
+            * the bare name of the tile provider, or a linkified URL if one
+            * is available
+            */
+            _("Map tiles provided by %s").format('OpenMapTiles')
+        );
 
         let provider = GeocodeFactory.getGeocoder().attribution;
         let providerUrl = GeocodeFactory.getGeocoder().attributionUrl;
@@ -723,19 +653,32 @@ export class MainWindow extends Adw.ApplicationWindow {
     }
 
     _onOpenShapeLayer() {
-        this._fileChooser = new ShapeLayerFileChooser({
-            transient_for: this,
+        let filters = new Gio.ListStore(Gtk.FileFilter.Gtype);
+
+        let allFilter = new Gtk.FileFilter({ name: _("All Layer Files") });
+        filters.append(allFilter);
+
+        ShapeLayer.SUPPORTED_TYPES.forEach((layerClass) => {
+            let filter = new Gtk.FileFilter({ name: layerClass.displayName });
+            layerClass.mimeTypes.forEach((type) => {
+                filter.add_mime_type(type);
+                allFilter.add_mime_type(type);
+            });
+
+            filters.append(filter);
         });
 
-        this._fileChooser.connect('response', (widget, response) => {
-            if (response === Gtk.ResponseType.ACCEPT) {
-                this._mapView.openShapeLayers(this._fileChooser.get_files());
+        let fileDialog = new Gtk.FileDialog({ title: _("Open Shape Layers"),
+                                              filters: filters });
+        fileDialog.open_multiple(this, null, (fileDialog, result) => {
+            try {
+                this._mapView.openShapeLayers(fileDialog.open_multiple_finish(result));
                 this._headerBarLeft.popdownLayersPopover();
                 this._actionBarLeft.popdownLayersPopover();
+            } catch {
+                // do nothing if the file dialog is dismissed
             }
-            this._fileChooser.destroy();
         });
-        this._fileChooser.show();
     }
 
     _showMainMenu() {
