@@ -48,24 +48,21 @@ import {OSMEditDialog} from './osmEditDialog.js';
 import {Place} from './place.js';
 import {PlaceMarker} from './placeMarker.js';
 import {RouteQuery} from './routeQuery.js';
-import * as Service from './service.js';
 import {ShapeLayer} from './shapeLayer.js';
 import {StoredRoute} from './storedRoute.js';
 import {TransitArrivalMarker} from './transitArrivalMarker.js';
 import {TransitBoardMarker} from './transitBoardMarker.js';
+import {TransitPathLayer} from './transitPathLayer.js';
 import {TransitWalkMarker} from './transitWalkMarker.js';
 import {TurnPointMarker} from './turnPointMarker.js';
 import {UserLocationMarker} from './userLocationMarker.js';
 import * as Utils from './utils.js';
+import * as URIS from './uris.js';
 
 const _LOCATION_STORE_TIMEOUT = 500;
 const MapMinZoom = 2;
 const MapMaxZoom = 19;
 
-/* threashhold for route color luminance when we consider it more or less
- * as white, and draw an outline on the path */
-const OUTLINE_LUMINANCE_THREASHHOLD = 0.9;
-
 // color used for turn-by-turn-based routes (non-transit)
 const TURN_BY_TURN_ROUTE_COLOR = '62a0ea';
 const TURN_BY_TURN_ROUTE_OUTLINE_COLOR = '1a5fb4';
@@ -73,14 +70,6 @@ const TURN_BY_TURN_ROUTE_OUTLINE_COLOR = '1a5fb4';
 // line width for route lines
 const ROUTE_LINE_WIDTH = 5;
 
-/* length of filled parts of dashed lines used for walking legs of transit
- * itineraries
- */
-const DASHED_ROUTE_LINE_FILLED_LENGTH = 5;
-
-// length of gaps of dashed lines used for walking legs of transit itineraries
-const DASHED_ROUTE_LINE_GAP_LENGTH = 5;
-
 // Maximum limit of file size (20 MB) that can be loaded without user confirmation
 const FILE_SIZE_LIMIT_MB = 20;
 
@@ -88,8 +77,6 @@ export class MapView extends Gtk.Overlay {
 
     static MapType = {
         LOCAL: 'MapsLocalSource',
-        STREET: 'MapsStreetSource',
-        AERIAL: 'MapsAerialSource',
         VECTOR: 'MapsVectorSource',
     }
 
@@ -170,8 +157,8 @@ export class MapView extends Gtk.Overlay {
             'route-to-here': {
                 onActivate: () => this._onRouteToHereActivated()
             },
-            'whats-here': {
-                onActivate: () => this._onWhatsHereActivated()
+            'clear-route': {
+                onActivate: () => this._onClearRouteActivated()
             },
             'copy-location': {
                 onActivate: () => this._onCopyLocationActivated()
@@ -188,6 +175,7 @@ export class MapView extends Gtk.Overlay {
         this._routeFromHereAction = actionGroup.lookup('route-from-here');
         this._routeToHereAction = actionGroup.lookup('route-to-here');
         this._addIntermediateDestinationAction = actionGroup.lookup('add-intermediate-destination');
+        this._clearRouteAction = actionGroup.lookup('clear-route');
 
         let builder = Gtk.Builder.new_from_resource('/org/gnome/Maps/ui/context-menu.ui');
         let menuModel = builder.get_object('context-menu');
@@ -292,25 +280,22 @@ export class MapView extends Gtk.Overlay {
         return map;
     }
 
-    /* create and store a route layer, pass true to get a dashed line */
-    _createRouteLayer(dashed, lineColor, outlineColor, width, outlineWidth = 1) {
-        let strokeColor = new Gdk.RGBA({ red:    Color.parseColor(lineColor, 0),
-                                         green:  Color.parseColor(lineColor, 1),
-                                         blue:   Color.parseColor(lineColor, 2),
-                                         alpha:  1.0 });
+    _createRGBA(lineColor) {
+        return new Gdk.RGBA({ red:    Color.parseColor(lineColor, 0),
+                              green:  Color.parseColor(lineColor, 1),
+                              blue:   Color.parseColor(lineColor, 2),
+                              alpha:  1.0 });
+    }
+
+    /* create and store a route layer */
+    _createRouteLayer(lineColor, outlineColor, width, outlineWidth = 1) {
+        let strokeColor = this._createRGBA(lineColor);
         let routeLayer = new Shumate.PathLayer({ viewport: this.map.viewport,
                                                  stroke_width: width,
                                                  stroke_color: strokeColor });
-        if (dashed)
-            routeLayer.set_dash([DASHED_ROUTE_LINE_FILLED_LENGTH,
-                                 DASHED_ROUTE_LINE_GAP_LENGTH]);
 
         if (outlineColor) {
-            let outlineStrokeColor =
-                new Gdk.RGBA({ red:   Color.parseColor(outlineColor, 0),
-                               green: Color.parseColor(outlineColor, 1),
-                               blue:  Color.parseColor(outlineColor, 2),
-                               alpha: 1.0 });
+            let outlineStrokeColor = this._createRGBA(outlineColor);
 
             routeLayer.outline_color = outlineStrokeColor;
             routeLayer.outline_width = outlineWidth;
@@ -407,6 +392,7 @@ export class MapView extends Gtk.Overlay {
             this._routeToHereAction.enabled = numPoints < RouteQuery.MAX_QUERY_POINTS;
             this._addIntermediateDestinationAction.enabled =
                 query.filledPoints.length >= 2 && numPoints < RouteQuery.MAX_QUERY_POINTS;
+            this._clearRouteAction.enabled = query.filledPoints.length >= 2;
         });
     }
 
@@ -420,7 +406,7 @@ export class MapView extends Gtk.Overlay {
             }
         }
 
-        return MapView.MapType.STREET;
+        return MapView.MapType.VECTOR;
     }
 
     getMapType() {
@@ -455,25 +441,11 @@ export class MapView extends Gtk.Overlay {
 
         this._mapType = mapType;
 
-        if (mapType !== MapView.MapType.VECTOR) {
-            if (this._stopListeningForVectorChanges) {
-                this._stopListeningForVectorChanges();
-            }
-        }
-
         let mapSource;
 
         if (mapType !== MapView.MapType.LOCAL) {
-            let tiles = Service.getService().tiles;
-
-            if (mapType === MapView.MapType.AERIAL && tiles.aerial)
-                mapSource = MapSource.createAerialSource();
-            else if (mapType === MapView.MapType.VECTOR && Shumate.VectorRenderer.is_supported()) {
-                mapSource = MapSource.createVectorSource();
-                this._listenForVectorChanges();
-            }
-            else
-                mapSource = MapSource.createStreetSource();
+            mapSource = MapSource.createVectorSource();
+            this._listenForVectorChanges();
 
             Application.settings.set('map-type', mapType);
         } else {
@@ -658,9 +630,7 @@ export class MapView extends Gtk.Overlay {
         if (result.confirmLoad) {
             let totalFileSizeMB = result.totalFileSizeMB;
 
-            let dialog = new Adw.MessageDialog ({
-                transient_for: this._mainWindow,
-                modal: true,
+            let dialog = new Adw.AlertDialog ({
                 heading: _("Do you want to continue?"),
                 body: _("You are about to open files with a total " +
                         "size of %s MB. This could take some time to" +
@@ -679,9 +649,8 @@ export class MapView extends Gtk.Overlay {
                 if (responseId === 'continue') {
                     this._loadShapeLayers(files);
                 }
-                dialog.destroy();
             });
-            dialog.present();
+            dialog.present(this._mainWindow);
         } else {
             this._loadShapeLayers(files);
         }
@@ -727,12 +696,17 @@ export class MapView extends Gtk.Overlay {
 
     goToGeoURI(uri) {
         try {
+            let [
+                geoUri,
+                zoom = Application.settings.get('zoom-level')
+            ] = URIS.parseAsGeoURI(uri);
             let location = new Location({ heading: -1 });
-            location.set_from_uri(uri);
+            location.set_from_uri(geoUri);
 
             let place = new Place({ location: location,
                                     name: location.description,
-                                    store: false });
+                                    store: false,
+                                    initialZoom: zoom });
             let marker = new PlaceMarker({ place: place,
                                            mapView: this });
             this._placeLayer.add_marker(marker);
@@ -975,10 +949,15 @@ export class MapView extends Gtk.Overlay {
             return;
         }
 
-        this.routingOpen = false;
         let placeMarker = new PlaceMarker({ place: place,
                                             mapView: this });
 
+        // remove marker when dismissing the bubble
+        placeMarker.bubble.connect('closed', () => {
+            this._placeLayer.remove_all();
+            Application.application.selected_place = null;
+        });
+
         this._placeLayer.add_marker(placeMarker);
         if (skipGoTo) {
             placeMarker.showBubble();
@@ -994,7 +973,7 @@ export class MapView extends Gtk.Overlay {
         this._clearRouteLayers();
         this._placeLayer.remove_all();
 
-        routeLayer = this._createRouteLayer(false, TURN_BY_TURN_ROUTE_COLOR,
+        routeLayer = this._createRouteLayer(TURN_BY_TURN_ROUTE_COLOR,
                                             TURN_BY_TURN_ROUTE_OUTLINE_COLOR,
                                             ROUTE_LINE_WIDTH + 4, 2);
         route.path.forEach((polyline) => routeLayer.add_node(polyline));
@@ -1024,6 +1003,8 @@ export class MapView extends Gtk.Overlay {
     }
 
     _showTransitItinerary(itinerary) {
+        const styleManager = Adw.StyleManager.get_default();
+
         this.gotoBBox(itinerary.bbox);
         this._clearRouteLayers();
         this._placeLayer.remove_all();
@@ -1031,17 +1012,11 @@ export class MapView extends Gtk.Overlay {
         this._turnPointMarker = null;
 
         itinerary.legs.forEach((leg, index) => {
-            let dashed = !leg.transit;
-            let color = leg.color;
-            let outlineColor = leg.textColor;
-            let hasOutline = Color.relativeLuminance(color) >
-                             OUTLINE_LUMINANCE_THREASHHOLD;
-            let routeLayer;
-            let lineWidth = ROUTE_LINE_WIDTH + (hasOutline ? 2 : 0);
+            const routeLayer =
+                new TransitPathLayer({ viewport: this.map.viewport, leg: leg });
 
-            routeLayer = this._createRouteLayer(dashed, color,
-                                                hasOutline ? outlineColor : null,
-                                                lineWidth);
+            this._routeLayers.push(routeLayer);
+            this.map.insert_layer_behind(routeLayer, this._userLocationLayer);
 
             /* if this is a walking leg and not at the start, "stitch" it
              * together with the end point of the previous leg, as the walk
@@ -1126,6 +1101,10 @@ export class MapView extends Gtk.Overlay {
         if (n_presses > 1)
             return;
 
+        // remove any showing place markers when clicking outside
+        this._placeLayer.remove_all();
+        Application.application.selected_place = null;
+
         this.map.grab_focus();
         gesture.set_state(Gtk.EventSequenceState.NONE);
     }
@@ -1196,15 +1175,8 @@ export class MapView extends Gtk.Overlay {
         query.points.last().place = place;
     }
 
-    _onWhatsHereActivated() {
-        GeocodeFactory.getGeocoder().reverse(this._latitude, this._longitude,
-                                      (place) => {
-            if (place) {
-                this.showPlace(place, true);
-            } else {
-                this._mainWindow.showToast(_("Nothing found here!"));
-            }
-        });
+    _onClearRouteActivated() {
+        Application.routeQuery.reset();
     }
 
     _onCopyLocationActivated() {
@@ -1221,11 +1193,10 @@ export class MapView extends Gtk.Overlay {
         let osmEdit = Application.osmEdit;
         /* if the user is not already signed in, show the account dialog */
         if (!osmEdit.isSignedIn) {
-            let dialog = osmEdit.createAccountDialog(this._mainWindow, true);
+            let dialog = osmEdit.createAccountDialog(true);
 
-            dialog.show();
+            dialog.present(this._mainWindow);
             dialog.connect('response', (dialog, response) => {
-                dialog.destroy();
                 if (osmEdit.isSignedIn)
                     this._addOSMLocation();
             });
